Construct a list of options to pass to the POWER API
Usage
.build_query(
community,
lonlat_identifier,
pars,
dates,
site_elevation,
wind_elevation,
wind_surface,
time_standard
)Arguments
- community
A validated value for
community.- lonlat_identifier
A list of values, a result of .check_lonlat.
- pars
A validated value from .check_pars.
- dates
A list of values, a result of .check_dates..
- site_elevation
A validated value passed by
check_inputs.- wind_elevation
A validated value passed by
check_inputs.- wind_surface
A validated value passed by
check_inputs.
Value
A list object of values to be passed to a crul object to
query
the 'POWER' 'API'.