Query the POWER API for Detailed Information on Available Parameter Groupings
Source:R/query_groupings.R
query_groupings.RdQueries the POWER API returning detailed information on available parameter
groupings. Results are grouped by community followed by temporal API, or if
global = TRUE, grouped by climatology then by available parameter types.
Author
Adam H. Sparks, adamhsparks@gmail.com